# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pyvelociraptor/api.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pyvelociraptor/api.proto',
  package='proto',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x18pyvelociraptor/api.proto\x12\x05proto\x1a\x1bgoogle/protobuf/empty.proto\"\'\n\nVQLRequest\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0b\n\x03VQL\x18\x01 \x01(\t\"$\n\x06VQLEnv\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x8b\x01\n\x10VQLCollectorArgs\x12\x1a\n\x03\x65nv\x18\x03 \x03(\x0b\x32\r.proto.VQLEnv\x12 \n\x05Query\x18\x02 \x03(\x0b\x32\x11.proto.VQLRequest\x12\x0f\n\x07max_row\x18\x04 \x01(\x04\x12\x10\n\x08max_wait\x18\x06 \x01(\x04\x12\x16\n\x0eops_per_second\x18\x18 \x01(\x02\"*\n\nVQLTypeMap\x12\x0e\n\x06\x63olumn\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\xbb\x01\n\x0bVQLResponse\x12\x10\n\x08Response\x18\x01 \x01(\t\x12\x0f\n\x07\x43olumns\x18\x02 \x03(\t\x12 \n\x05types\x18\x08 \x03(\x0b\x32\x11.proto.VQLTypeMap\x12\x10\n\x08query_id\x18\x05 \x01(\x04\x12\x0c\n\x04part\x18\x06 \x01(\x04\x12 \n\x05Query\x18\x03 \x01(\x0b\x32\x11.proto.VQLRequest\x12\x11\n\ttimestamp\x18\x04 \x01(\x04\x12\x12\n\ntotal_rows\x18\x07 \x01(\x04\x32{\n\x03\x41PI\x12\x38\n\x05Query\x12\x17.proto.VQLCollectorArgs\x1a\x12.proto.VQLResponse\"\x00\x30\x01\x12:\n\nWriteEvent\x12\x12.proto.VQLResponse\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_VQLREQUEST = _descriptor.Descriptor(
  name='VQLRequest',
  full_name='proto.VQLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='proto.VQLRequest.Name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='VQL', full_name='proto.VQLRequest.VQL', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=103,
)


_VQLENV = _descriptor.Descriptor(
  name='VQLEnv',
  full_name='proto.VQLEnv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proto.VQLEnv.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.VQLEnv.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=141,
)


_VQLCOLLECTORARGS = _descriptor.Descriptor(
  name='VQLCollectorArgs',
  full_name='proto.VQLCollectorArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='env', full_name='proto.VQLCollectorArgs.env', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Query', full_name='proto.VQLCollectorArgs.Query', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_row', full_name='proto.VQLCollectorArgs.max_row', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_wait', full_name='proto.VQLCollectorArgs.max_wait', index=3,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ops_per_second', full_name='proto.VQLCollectorArgs.ops_per_second', index=4,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=283,
)


_VQLTYPEMAP = _descriptor.Descriptor(
  name='VQLTypeMap',
  full_name='proto.VQLTypeMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='proto.VQLTypeMap.column', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.VQLTypeMap.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=285,
  serialized_end=327,
)


_VQLRESPONSE = _descriptor.Descriptor(
  name='VQLResponse',
  full_name='proto.VQLResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='proto.VQLResponse.Response', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Columns', full_name='proto.VQLResponse.Columns', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='types', full_name='proto.VQLResponse.types', index=2,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='proto.VQLResponse.query_id', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='part', full_name='proto.VQLResponse.part', index=4,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Query', full_name='proto.VQLResponse.Query', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='proto.VQLResponse.timestamp', index=6,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_rows', full_name='proto.VQLResponse.total_rows', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=517,
)

_VQLCOLLECTORARGS.fields_by_name['env'].message_type = _VQLENV
_VQLCOLLECTORARGS.fields_by_name['Query'].message_type = _VQLREQUEST
_VQLRESPONSE.fields_by_name['types'].message_type = _VQLTYPEMAP
_VQLRESPONSE.fields_by_name['Query'].message_type = _VQLREQUEST
DESCRIPTOR.message_types_by_name['VQLRequest'] = _VQLREQUEST
DESCRIPTOR.message_types_by_name['VQLEnv'] = _VQLENV
DESCRIPTOR.message_types_by_name['VQLCollectorArgs'] = _VQLCOLLECTORARGS
DESCRIPTOR.message_types_by_name['VQLTypeMap'] = _VQLTYPEMAP
DESCRIPTOR.message_types_by_name['VQLResponse'] = _VQLRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VQLRequest = _reflection.GeneratedProtocolMessageType('VQLRequest', (_message.Message,), {
  'DESCRIPTOR' : _VQLREQUEST,
  '__module__' : 'pyvelociraptor.api_pb2'
  # @@protoc_insertion_point(class_scope:proto.VQLRequest)
  })
_sym_db.RegisterMessage(VQLRequest)

VQLEnv = _reflection.GeneratedProtocolMessageType('VQLEnv', (_message.Message,), {
  'DESCRIPTOR' : _VQLENV,
  '__module__' : 'pyvelociraptor.api_pb2'
  # @@protoc_insertion_point(class_scope:proto.VQLEnv)
  })
_sym_db.RegisterMessage(VQLEnv)

VQLCollectorArgs = _reflection.GeneratedProtocolMessageType('VQLCollectorArgs', (_message.Message,), {
  'DESCRIPTOR' : _VQLCOLLECTORARGS,
  '__module__' : 'pyvelociraptor.api_pb2'
  # @@protoc_insertion_point(class_scope:proto.VQLCollectorArgs)
  })
_sym_db.RegisterMessage(VQLCollectorArgs)

VQLTypeMap = _reflection.GeneratedProtocolMessageType('VQLTypeMap', (_message.Message,), {
  'DESCRIPTOR' : _VQLTYPEMAP,
  '__module__' : 'pyvelociraptor.api_pb2'
  # @@protoc_insertion_point(class_scope:proto.VQLTypeMap)
  })
_sym_db.RegisterMessage(VQLTypeMap)

VQLResponse = _reflection.GeneratedProtocolMessageType('VQLResponse', (_message.Message,), {
  'DESCRIPTOR' : _VQLRESPONSE,
  '__module__' : 'pyvelociraptor.api_pb2'
  # @@protoc_insertion_point(class_scope:proto.VQLResponse)
  })
_sym_db.RegisterMessage(VQLResponse)



_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='proto.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=519,
  serialized_end=642,
  methods=[
  _descriptor.MethodDescriptor(
    name='Query',
    full_name='proto.API.Query',
    index=0,
    containing_service=None,
    input_type=_VQLCOLLECTORARGS,
    output_type=_VQLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WriteEvent',
    full_name='proto.API.WriteEvent',
    index=1,
    containing_service=None,
    input_type=_VQLRESPONSE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)



"""Helper functions to deal with pandas.

# How to use this code in a jupyter notebook

First initialize pandas options to prevent eliding output or rows.

1. Create an api config with the velociraptor server:

$ velociraptor --config server.config.yaml config api_config --name Mike

2. Grant the API user all query permissions

$ velociraptor --config server.config.yaml acl grant '{"all_query": true}'

3. Export the API service or port forward using SSH to the server

$ ssh -L 8001:127.0.0.1:8001 velociraptor.example.com

4. On your workstation copy the API config to ~/.pyvelociraptorrc or

$ export VELOCIRAPTOR_API_FILE=/path/to/api/file.yaml

5. Install Jupyter, Pandas and pyvelociraptor (preferably inside a virtualenv)

$ pip install jupyter pandas pyvelociraptor

6. Start jupyter

$ jupyter notebook


In the first cell initialize the pandas options

```
import pandas
from pyvelociraptor import velo_pandas

pandas.set_option('display.max_colwidth', None)
pandas.set_option('display.max_columns', None)
pandas.set_option('display.max_rows', None)
```

Calling velo_pandas.DataFrameQuery(vql) will connect to the API server
specified in the api config file (either from ~/.pyvelociraptorrc or the
VELOCIRAPTOR_API_FILE environment ) and run the VQL query
specified. The result is a python dict structured in a way that can
initialize a pandas DataFrame directly. You can then use regular
pandas visualization or plotting functions to explore the data (see
any pandas tutorial or book).

Each cell in the notebook can create a new data frame and explore it.

```
df = pandas.DataFrame(velo_pandas.DataFrameQuery(```
  SELECT ConsumerDetails, FilterDetails, Fqdn FROM hunt_results(hunt_id='H.380432d0',
 artifact='Windows.Persistence.PermanentWMIEvents')
 WHERE NOT ConsumerDetails.Name =~ '(SCM Event Log Consumer|DellCommandPowerManager.*EventConsumer)'
 LIMIT 50 ```))
df.head(500)
```

You can also add query parameters as keyword args:

```
HuntId = 'H.380432d0'
df = pandas.DataFrame(velo_pandas.DataFrameQuery(```
  SELECT ConsumerDetails, FilterDetails, Fqdn FROM hunt_results(hunt_id=HuntId,
 artifact='Windows.Persistence.PermanentWMIEvents')
 WHERE NOT ConsumerDetails.Name =~ '(SCM Event Log Consumer|DellCommandPowerManager.*EventConsumer)'
 LIMIT 50 ```, HuntId=HuntId))
df.head(500)
```

"""
import json
import grpc
import os
import os.path

import pyvelociraptor

from pyvelociraptor import api_pb2
from pyvelociraptor import api_pb2_grpc


def DataFrameQuery(query, timeout=600, config=None, **kw):
    if config is None:
        config = pyvelociraptor.LoadConfigFile()

    creds = grpc.ssl_channel_credentials(
        root_certificates=config["ca_certificate"].encode("utf8"),
        private_key=config["client_private_key"].encode("utf8"),
        certificate_chain=config["client_cert"].encode("utf8"))

    # This option is required to connect to the grpc server by IP - we
    # use self signed certs.
    options = (('grpc.ssl_target_name_override', "VelociraptorServer",),)

    # The first step is to open a gRPC channel to the server..
    with grpc.secure_channel(config["api_connection_string"],
                             creds, options) as channel:
        stub = api_pb2_grpc.APIStub(channel)

        # The request consists of one or more VQL queries. Note that
        # you can collect server artifacts by simply naming them using the
        # "Artifact" plugin (i.e. `SELECT * FROM Artifact.Server.Hunts.List()` )
        request = api_pb2.VQLCollectorArgs(
            max_wait=1,
            env=[api_pb2.VQLEnv(key=k, value=v) for k,v in kw.items()],
            Query=[api_pb2.VQLRequest(
                Name="Query",
                VQL=query,
            )])

        result = {}
        for response in stub.Query(request):
            for row in json.loads(response.Response):
                for c in response.Columns:
                    result.setdefault(c, []).append(row.get(c))

        return result



#!/usr/bin/python

"""Example Velociraptor api client.

This example demonstrates how to connect to the Velociraptor server
and write an event to a single Artifact queue.
"""
import argparse
import collections
import json
import grpc
import yaml

from pyvelociraptor import api_pb2
from pyvelociraptor import api_pb2_grpc

def run(config, queue, event, columns):
    # Fill in the SSL params from the api_client config file. You can get such a file:
    # velociraptor --config server.config.yaml config api_client > api_client.conf.yaml
    creds = grpc.ssl_channel_credentials(
        root_certificates=config["ca_certificate"].encode("utf8"),
        private_key=config["client_private_key"].encode("utf8"),
        certificate_chain=config["client_cert"].encode("utf8"))

    # This option is required to connect to the grpc server by IP - we
    # use self signed certs.
    options = (('grpc.ssl_target_name_override', "VelociraptorServer",),)

    # The first step is to open a gRPC channel to the server..
    with grpc.secure_channel(config["api_connection_string"],
                             creds, options) as channel:
        stub = api_pb2_grpc.APIStub(channel)

        # The request consists of one or more VQL queries. Note that
        # you can collect artifacts by simply naming them using the
        # "Artifact" plugin.
        request = api_pb2.VQLResponse(
            Response=event,
            Columns=columns,
            Query=api_pb2.VQLRequest(Name=queue))

        err = stub.WriteEvent(request)
        print(err)

def main():
    parser = argparse.ArgumentParser(
        description="Sample Velociraptor query client.",
        epilog='Example: pyvelociraptor_push_event api_client.yaml Windows.Event.Monitor'
        "'{\"Time\": ....}'")

    parser.add_argument('config', type=str,
                        help='Path to the api_client config. You can generate such '
                        'a file with "velociraptor config api_client"')
    parser.add_argument('queue', type=str, help='The artifact name this event will go to.')
    parser.add_argument('event', type=str, help='A JSON formatted event to send')
    args = parser.parse_args()

    # Parse the event to determine the columns
    event_data = json.loads(args.event, object_pairs_hook=collections.OrderedDict)
    event = args.event

    # Let the user just supply one event if they want
    if not isinstance(event_data, list):
        event_data = [event_data,]
        event = json.dumps(event_data)

    columns = event_data[0].keys()

    config = yaml.safe_load(open(args.config).read())
    run(config, args.queue, event, columns)

if __name__ == '__main__':
    main()



#!/usr/bin/python

"""Example Velociraptor api client.

This example demonstrates how to connect to the Velociraptor server
and issue a server side VQL query.

In this example we may issue event queries which stream results slowly
to the api client. This demonstrates how to build reactive post
processing scripts as required.


Some example queries to try:

Get basic information about the server:

 SELECT * from info()


Get server load as a data stream (This will never terminate and return
data points every 10 seconds):

 SELECT * from Artifact.Generic.Client.Stats()


Get an event for every execution of psexecsvc on any deployed
machine. The event can be handled in this python loop as required. The
python script will block until psexec is detected.

   SELECT * from watch_monitoring(
          artifact='Windows.Events.ProcessCreation')
   WHERE Name =~ '(?i)psexesvc'

"""
import argparse
import json
import grpc
import yaml

import pyvelociraptor
from pyvelociraptor import api_pb2
from pyvelociraptor import api_pb2_grpc

def run(config, query):
    # Fill in the SSL params from the api_client config file. You can get such a file:
    # velociraptor --config server.config.yaml config api_client > api_client.conf.yaml
    creds = grpc.ssl_channel_credentials(
        root_certificates=config["ca_certificate"].encode("utf8"),
        private_key=config["client_private_key"].encode("utf8"),
        certificate_chain=config["client_cert"].encode("utf8"))

    # This option is required to connect to the grpc server by IP - we
    # use self signed certs.
    options = (('grpc.ssl_target_name_override', "VelociraptorServer",),)

    # The first step is to open a gRPC channel to the server..
    with grpc.secure_channel(config["api_connection_string"],
                             creds, options) as channel:
        stub = api_pb2_grpc.APIStub(channel)

        # The request consists of one or more VQL queries. Note that
        # you can collect artifacts by simply naming them using the
        # "Artifact" plugin.
        request = api_pb2.VQLCollectorArgs(
            max_wait=1,
            Query=[api_pb2.VQLRequest(
                Name="Test",
                VQL=query,
            )])

        # This will block as responses are streamed from the
        # server. If the query is an event query we will run this loop
        # forever.
        for response in stub.Query(request):

            # Each response represents a list of rows. The columns are
            # provided in their own field as an array, to ensure
            # column order is preserved if required. If you dont care
            # about column order just ignore the Columns field.
            # print("Columns %s:" % response.Columns)

            # The actual payload is a list of dicts. Each dict has
            # column names as keys and arbitrary (possibly nested)
            # values.
            package = json.loads(response.Response)
            print (package)

def main():
    parser = argparse.ArgumentParser(
        description="Sample Velociraptor query client.",
        epilog='Example: client_example.py api_client.yaml '
    '" SELECT * from Artifact.Generic.Client.Stats() "')

    parser.add_argument('--config', type=str,
                        help='Path to the api_client config. You can generate such '
                        'a file with "velociraptor config api_client"')
    parser.add_argument('query', type=str, help='The query to run.')

    args = parser.parse_args()

    config = pyvelociraptor.LoadConfigFile(args.config)
    run(config, args.query)

if __name__ == '__main__':
    main()



#!/usr/bin/env python

"""PyVelociraptor are the python bindings for talking with Velociraptor."""

__author__ = "Velocidex <support@velocidex.com>"

import io
from distutils.core import setup

setup(
    name="pyvelociraptor",
    version="0.1.2",
    packages=['pyvelociraptor'],
    description="PyVelociraptor is the python binding for the Velociraptor API",
    license="GPL",
    url="https://github.com/Velocidex/pyvelociraptor",
    author="The Velociraptor Team",
    author_email="support@velocidex.com",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
    ],
    install_requires=[
        "grpcio",
        "grpcio-tools",
        "pyyaml",
    ],
    entry_points="""

    [console_scripts]
    pyvelociraptor = pyvelociraptor.client_example:main
    pyvelociraptor_push_event = pyvelociraptor.push_event:main
    """,
)



import os
import yaml

def LoadConfigFile(config_file=None):
    if config_file is None:
        config_file = os.environ.get("VELOCIRAPTOR_API_FILE")

    if config_file is None:
        config_file = os.path.join(os.environ.get("HOME"), ".pyvelociraptorrc")

    try:
        config = yaml.safe_load(open(config_file).read())
    except Exception as e:
        raise TypeError("Unable to parse config file from %s: %s" % (config_file, e))

    return config
